@@ -16,29 +16,29 @@
 // OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 // DEALINGS IN THE SOFTWARE.
 
+pub use self::module::PyModule;
 pub use self::object::PyObject;
 pub use self::typeobject::PyType;
-pub use self::module::PyModule;
 
-pub use self::string::{PyBytes, PyString, PyStringData};
-#[cfg(feature="python27-sys")]
-pub use self::string::PyUnicode;
-#[cfg(feature="python3-sys")]
+#[cfg(feature = "python3-sys")]
 pub use self::string::PyString as PyUnicode;
+#[cfg(feature = "python27-sys")]
+pub use self::string::PyUnicode;
+pub use self::string::{PyBytes, PyString, PyStringData};
 
-pub use self::iterator::PyIterator;
 pub use self::boolobject::PyBool;
-pub use self::tuple::{PyTuple, NoArgs};
-pub use self::dict::PyDict;
-pub use self::set::PySet;
-pub use self::list::PyList;
-#[cfg(feature="python27-sys")]
-pub use self::num::PyInt;
-#[cfg(feature="python3-sys")]
-pub use self::num::PyLong as PyInt;
-pub use self::num::{PyLong, PyFloat};
-pub use self::sequence::PySequence;
 pub use self::capsule::PyCapsule;
+pub use self::dict::PyDict;
+pub use self::iterator::PyIterator;
+pub use self::list::PyList;
+#[cfg(feature = "python27-sys")]
+pub use self::num::PyInt;
+#[cfg(feature = "python3-sys")]
+pub use self::num::PyLong as PyInt;
+pub use self::num::{PyFloat, PyLong};
+pub use self::sequence::PySequence;
+pub use self::set::PySet;
+pub use self::tuple::{NoArgs, PyTuple};
 
 #[macro_export(local_inner_macros)]
 macro_rules! pyobject_newtype(
@@ -82,7 +82,11 @@ macro_rules! pyobject_newtype(
                     if ::ffi::$checkfunction(obj.as_ptr()) != 0 {
                         Ok($name(obj))
                     } else {
-                        Err(::python::PythonObjectDowncastError(py))
+                        Err(::python::PythonObjectDowncastError::new(
+                            py,
+                            _cpython__objects__stringify!($name),
+                            obj.get_type(py)
+                        ))
                     }
                 }
             }
@@ -93,7 +97,11 @@ macro_rules! pyobject_newtype(
                     if ::ffi::$checkfunction(obj.as_ptr()) != 0 {
                         Ok(::std::mem::transmute(obj))
                     } else {
-                        Err(::python::PythonObjectDowncastError(py))
+                        Err(::python::PythonObjectDowncastError::new(
+                            py,
+                            _cpython__objects__stringify!($name),
+                            obj.get_type(py)
+                        ))
                     }
                 }
             }
@@ -113,34 +121,41 @@ macro_rules! pyobject_newtype(
 
 macro_rules! extract(
     ($obj:ident to $t:ty; $(#[$meta:meta])* $py:ident => $body: block) => {
-        impl <'source> ::conversion::FromPyObject<'source>
+        impl <'s> ::conversion::FromPyObject<'s>
             for $t
         {
             $(#[$meta])*
-            fn extract($py: Python, $obj: &'source PyObject) -> PyResult<Self> {
+            fn extract($py: Python, $obj: &'s PyObject) -> PyResult<Self> {
                 $body
             }
         }
     }
 );
 
-mod object;
-mod typeobject;
-mod module;
-mod string;
-mod dict;
-mod set;
-mod iterator;
-mod boolobject;
-mod tuple;
-mod list;
-mod num;
-mod sequence;
-mod capsule;
-pub mod exc;
+#[doc(hidden)]
+#[macro_export]
+macro_rules! _cpython__objects__stringify {
+    ($($inner:tt)*) => {
+        stringify! { $($inner)* }
+    }
+}
 
-#[cfg(feature="python27-sys")]
+mod boolobject;
+mod capsule;
+mod dict;
+pub mod exc;
+mod iterator;
+mod list;
+mod module;
+mod num;
+mod object;
+mod sequence;
+mod set;
+mod string;
+mod tuple;
+mod typeobject;
+
+#[cfg(feature = "python27-sys")]
 pub mod oldstyle;
 
 mod tests;
-
