@@ -16,8 +16,8 @@
 // OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 // DEALINGS IN THE SOFTWARE.
 
-use {Python, PyDict, ToPyObject, PyInt};
 use std::collections::{BTreeMap, HashMap};
+use {PyDict, PyInt, Python, ToPyObject};
 
 // TODO: move these tests into the dict module
 #[test]
@@ -31,7 +31,7 @@ fn test_hashmap_to_python() {
     let py_map = map.to_py_object(py);
 
     assert!(py_map.len(py) == 1);
-    assert!( py_map.get_item(py, 1).unwrap().extract::<i32>(py).unwrap() == 1);
+    assert!(py_map.get_item(py, 1).unwrap().extract::<i32>(py).unwrap() == 1);
 }
 
 #[test]
@@ -45,6 +45,5 @@ fn test_btreemap_to_python() {
     let py_map = map.to_py_object(py);
 
     assert!(py_map.len(py) == 1);
-    assert!( py_map.get_item(py, 1).unwrap().extract::<i32>(py).unwrap() == 1);
+    assert!(py_map.get_item(py, 1).unwrap().extract::<i32>(py).unwrap() == 1);
 }
-
